# Components
-- Description. --

## Input Components

#### InputBox
It uses [bootstrap checkbox & radios](https://v4-alpha.getbootstrap.com/components/forms/#checkboxes-and-radios) to render a choice/box input. 

##### Examples

**Checkbox:** A standard checkbox.
````vue
<div id="app">
  Value: {{ checkbox }} <br>
  
  <input-box v-model="checkbox" title="Accept terms & conditions."></input-box> 
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ checkbox: false })
})
</script>
````

**Checkbox:** An alternate checkbox.
````vue
<div id="app">
  Value: {{ checkbox }} <br>
  
  <input-box v-model="checkbox" title="Accept terms" custom></input-box> 
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ checkbox: true })
})
</script>
````

**Radio:** A box input can be formatted as a radio element. This means it is an exclusive option. A standard radio input.

````vue
<div id="app">
  Value: {{ radio }} <br>
  
  <input-box v-model="radio" radio="1" title="Radio box 1"></input-box>
  <input-box v-model="radio" radio="2" title="Radio box 2"></input-box> 
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ radio: '1' })
})
</script>
````

**Radio:** An alternate radio input.
````vue
<div id="app">
   Value: {{ radio }} <br>

  <input-box v-model="radio" radio="1" title="Styled Radio 1" custom></input-box>
  <input-box v-model="radio" radio="2" title="Styled Radio 2" custom></input-box> 
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ radio: '1' })
})
</script>
````

**Checkbox:** Inline checkbox & radio.
````vue
<div id="app">
  Checkbox: {{ checkbox }} <br>
  Radio: {{ radio }}  <br>
 
  <input-box v-model="checkbox" checkbox="1" title="Checkbox 1" inline></input-box>
  <input-box v-model="checkbox" checkbox="2" title="Checkbox 2" inline custom></input-box> 
 
  <input-box v-model="radio" radio="3" title="Radio 3" inline></input-box> 
  <input-box v-model="radio" radio="4" title="Radio 4" inline custom></input-box> 
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ checkbox: '1', radio: '3' })
})
</script>
````

**Checkbox:** Multiple options. Set initial value to an `Array`.
````vue
<div id="app">
  Value: {{ checkbox }} <br>
  
  <input-box v-model="checkbox" checkbox="1" title="Checkbox 1" inline></input-box>
  <input-box v-model="checkbox" checkbox="2" title="Checkbox 2" inline></input-box> 
  <input-box v-model="checkbox" checkbox="3" title="Checkbox 3" inline></input-box> 
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ checkbox: [] })
})
</script>
````

##### Model
| Name   | Value   |
| ------ | ------- |
| value  | value   |
| event  | input   |

##### Props
| Name                  | Type                    | Default               | Required | Remarks             
| :-------------------- | :---------------------- | --------------------- |----------| --------------      
| autocomplete          | Boolean, String         | -                     | - | Same as HTML attribute
| autofocus             | Boolean                 | `false`               | - | Same as HTML attribute
| checkbox              | Boolean, String         | `true`                | - | `radio` cannot be used.    
| inline                | Boolean                 | `false`               | - |                            
| radio                 | Boolean, String         | `undefined`           | - | `checkbox` cannot be used. 
| value                 | Boolean, Array          | -                     | yes |    

#### InputButton
It uses [bootstrap button](https://v4-alpha.getbootstrap.com/components/buttons/) to render a form
button. 

##### Examples
````vue
<div id="app">
  <input-button>Primary Button</input-button>
  <input-button theme="secondary">Secondary Button</input-button>
  <input-button theme="info">Info Button</input-button>
  <input-button theme="success">Success Button</input-button>
  <input-button theme="warning">Warning Button</input-button>
  <input-button theme="danger">Danger Button</input-button> <br> <br>
  <input-button type="submit">Submit Button</input-button>
  <input-button value="Button with value prop"></input-button>
  <input-button v-model="title"></input-button>
</div>

<script>
new Vue({
  el: '#app',
  data: () => ({ title: 'Button with v-model' })
})
</script>
````

##### Model
 Name   | Value   
--------|---------
 value  | value   
 event  | -       

##### Props
 Name   | Type   | Default   | Remarks                                                                             
------- | ------ | --------- | -------                                                                          
 icon   | String | -         | Use FontAwesome icon class without `fa` prefix                                      
 theme  | String | `primary` | Bootstrap button themes, e.g. `success` would add `btn-success` class on the button 
 type   | String | `button`  | Possible values: `button` or `submit`                                               
 value  | String | `null`    | Button text                                                                        

##### Slots
 Name    | Description  
------  | -------------
default | Button text  

#### InputSearch
A search field with typeahead suggestion that respects bootstrap input style.

##### Examples

A simple search field.
````vue
<div id="app">
  <input-search v-model="search"></input-search>
</div>

<script>
new Vue({
  el: '#app',
  data: () => ({ search: '' })
})
</script>
````

With placeholder & typeahead suggestion.
````vue
<div id="app">
  <input-search v-model="search" :suggestion="suggestion"
                placeholder='Try typing "foo bar"...'></input-search>
</div>

<script>
new Vue({
  el: '#app',
  data: () => ({ search: '' }),
  
  computed: {
    suggestion: () => 'foo bar',
  }
})
</script>
````

With title & subtitle and required.
````vue
<div id="app">
  <input-search title="Search a foo" subtitle="This would search some foos."
                v-model="search" required></input-search>
</div>

<script>
new Vue({
  el: '#app',
  data: () => ({ search: '' })
})
</script>
````

With title & subtitle using slots.
````vue
<div id="app">
  <input-search v-model="search" title="yes" subtitle="yes">
    Search a <strong>foo</strong>
      
    <template slot="subtitle">
      This would <em>search</em> some <strong>foo</strong>s.
    </template>
  </input-search>
</div>

<script>
new Vue({
  el: '#app',
  data: () => ({ search: '' })
})
</script>
````

##### Model
| Name   | Value   |
| ------ | ------- |
| value  | value   |
| event  | input   |

##### Props
| Name                  | Type                    | Default               | Required | Remarks                    
| :-------------------- | :---------------------- | --------------------- | -------- | --------------                      
| autocomplete          | Boolean, String         | -                     | - | Same as HTML attribute
| autofocus             | Boolean                 | `false`               | - | Same as HTML attribute
| errors                | [ErrorBag](/helpers#ErrorBag)                | Injected by [formHelper](/mixins#formHelper) | - | It is automatically set to correct value using `provide/inject`. In most cases you won't have to care about it.  
| name                  | String                  | `null`                | - | Same as HTML attribute
| input-class            | String                  | `null`               | - | Add CSS `class` to underlying `<input>` element.
| input-name            | String                  | `null`                | - | Used for accessing validation errors. <br> If not provided, `v-model` expression is used. <br> e.g. `... v-model="foo" ...` then `input-name` is `'foo'` <br> e.g. `... v-model="attributes.bar" ...` then `input-name` is `'bar'`
| placeholder           | String                  | -                     | - | Same as HTML attribute
| required              | Boolean                 | -                     | - | Same as HTML attribute
| subtitle              | String                  | `null`                | - | Input field helper text
| suggestion            | String                  | -                     | - | Typeahead shadow text 
| title                 | String                  | `null`                | - | Input field cue
| value                 | Boolean, Array          | -                     | yes |

##### Slots
Name | Description 
-----|-------------
default | Input field title
subtitle | Input field subtitle

#### InputSelect
A native `<select>` element with bootstrap custom input style.

##### Examples
A simple select field.

````vue
<div id="app">
  <input-select v-model="select" :options="options"></input-select>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ select: '' }),
  
  computed: {
    options: () => [
      { id: 1, name: 'Foo' },
      { id: 2, name: 'Bar' },
      { id: 3, name: 'Baz' },
      { id: 4, name: 'Bam' },
    ]
  }
})
</script>
````

A select field with title, subtitle & placeholder.
````vue
<div id="app">
  <input-select v-model="select" :options="options"
                title="Foo Selector"
                subtitle="You must choose one of these."
                placeholder="Select one...." required></input-select>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ select: '' }),
  
  computed: {
    options: () => [
      { id: 1, name: 'Foo' },
      { id: 2, name: 'Bar' },
      { id: 3, name: 'Baz', disabled: true },
      { id: 4, name: 'Bam' },
    ]
  }
})
</script>
````

With title & subtitle using slots.
````vue
<div id="app">
  <input-select v-model="select" title="yes" subtitle="yes" :options="options">
    Select a <strong>foo</strong>
      
    <template slot="subtitle">
      You can <em>choose</em> some <strong>foo</strong>s.
    </template>
  </input-select>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ select: '' }),
  
  computed: {
    options: () => [
      { id: 1, name: 'Foo' },
      { id: 2, name: 'Bar' },
      { id: 3, name: 'Baz', disabled: true },
      { id: 4, name: 'Bam' },
    ]
  }
})
</script>
````

A select field with custom value, display & disabled props.
````vue
<div id="app">
  <input-select v-model="select" :options="options"
                value-key="val" display-key="disp"
                disabled-key="is"></input-select>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ select: '' }),
  
  computed: {
    options: () => [
      { val: 1, disp: 'Foo', is: false },
      { val: 2, disp: 'Bar', is: false },
      { val: 3, disp: 'Baz', is: true },
      { val: 4, disp: 'Bam', is: false },
    ]
  }
})
</script>
````


##### Model
| Name   | Value   |
| ------ | ------- |
| value  | value   |
| event  | input   |

##### Props
| Name                  | Type                    | Default               | Required | Remarks                    
| :-------------------- | :---------------------- | --------------------- | -------- | --------------                      
| autocomplete          | Boolean, String         | -                     | - | Same as HTML attribute
| autofocus             | Boolean                 | `false`               | - | Same as HTML attribute
| disabled-key          | String                 | `'disabled'`           | - | Disables option in select dropdown
| display-key           | String                 | `'name'`               | - | Visible value of the option
| errors                | [ErrorBag](/helpers#ErrorBag) | Injected by [formHelper](/mixins#formHelper) | - | It is automatically set to correct value using `provide/inject`. In most cases you won't have to care about it.  
| name                  | String                  | `null`                | - | Same as HTML attribute
| input-class            | String                  | `null`               | - | Add CSS `class` to underlying `<input>` element.
| input-name            | String                  | `null`                | - | Used for accessing validation errors. <br> If not provided, `v-model` expression is used. <br> e.g. `... v-model="foo" ...` then `input-name` is `'foo'` <br> e.g. `... v-model="attributes.bar" ...` then `input-name` is `'bar'`
| options               | Array                  | -                      | yes | Options for select dropdown. An array of objects where each object is an option.
| placeholder           | String                  | -                     | - | Same as HTML attribute
| required              | Boolean                 | -                     | - | Same as HTML attribute
| subtitle              | String                  | `null`                | - | Input field helper text
| suggestion            | String                  | -                     | - | Typeahead shadow text 
| title                 | String                  | `null`                | - | Input field cue
| value                 | Boolean, Array          | -                     | yes |
| value-key             | String                 | `'id'`                 | - | Actual value of the option

##### Slots
Name | Description 
-----|-------------
default | Input field title
subtitle | Input field subtitle


#### InputSwitch
Toggle switches are missing from bootstrap. It provides an alternate UI for [InputBox](#InputBox) with same [API](#props). 


````vue
<div id="app">
  Value: {{ checkbox }} <br>
  
  <input-switch v-model="checkbox" title="Accept terms & conditions."></input-switch> 
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ checkbox: false })
})
</script>
````

#### InputText
It wraps default `<input>` element with bootstrap styles & Vue magic.

##### Examples
A simple input field.
````vue
<div id="app">
  <input-text v-model="name"></input-text>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ name: '' })
})
</script>
````

An input field with title, subtitle & placeholder.
````vue
<div id="app">
  <input-text v-model="name" title="Your Name" subtitle="Give you full name e.g. John Doe" placeholder="xxxxx xxx"></input-text>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ name: '' })
})
</script>
````

An input field with custom title & subtitle.
````vue
<div id="app">
  <input-text v-model="name" title="yes" subtitle="yes" placeholder="xxxxx xxx">
    Your <strong>Name</strong>
    
    <template slot="subtitle">
      Give you full name <em><strong>e.g.</strong> John Doe</em>
    </template>
  </input-text>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ name: '' })
})
</script>
````

A numeric input field with min & max limits.
````vue
<div id="app">
  <input-text v-model="name" type="number" min="1" max="10"></input-text>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ name: '' })
})
</script>
````

A phone number input field with autocomplete.
````vue
<div id="app">
  <input-text v-model="name" type="tel" autocomplete="tel"></input-text>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ name: '' })
})
</script>
````

An email number input field with autocomplete.
````vue
<div id="app">
  <input-text v-model="name" type="email" autocomplete="email"></input-text>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ name: '' })
})
</script>
````

##### Model
| Name   | Value   |
| ------ | ------- |
| value  | value   |
| event  | input   |

##### Props
| Name                  | Type                    | Default               | Required | Remarks                    
| :-------------------- | :---------------------- | --------------------- | -------- | --------------                      
| autocomplete          | Boolean, String         | -                     | - | Same as HTML attribute
| autofocus             | Boolean                 | `false`               | - | Same as HTML attribute
| errors                | [ErrorBag](/helpers#ErrorBag) | Injected by [formHelper](/mixins#formHelper) | - | It is automatically set to correct value using `provide/inject`. In most cases you won't have to care about it.  
| name                  | String                  | `null`                | - | Same as HTML attribute
| input-class            | String                  | `null`               | - | Add CSS `class` to underlying `<input>` element.
| input-name            | String                  | `null`                | - | Used for accessing validation errors. <br> If not provided, `v-model` expression is used. <br> e.g. `... v-model="foo" ...` then `input-name` is `'foo'` <br> e.g. `... v-model="attributes.bar" ...` then `input-name` is `'bar'`
| placeholder           | String                  | -                     | - | Same as HTML attribute
| required              | Boolean                 | -                     | - | Same as HTML attribute
| subtitle              | String                  | `null`                | - | Input field helper text
| suggestion            | String                  | -                     | - | Typeahead shadow text 
| title                 | String                  | `null`                | - | Input field cue
| type                  | String                  | `'text'`              | - | Same as HTML attribute on `<input>` element
| value                 | Boolean, Array          | -                     | yes |

##### Slots
Name | Description 
-----|-------------
default | Input field title
subtitle | Input field subtitle

#### InputTextarea
A textarea field, styled with bootstrap.

##### Examples
A simple textarea field
````vue
<div id="app">
  <input-textarea v-model="text"></input-textarea>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ text: '' })
})
</script>
````

A simple textarea field
````vue
<div id="app">
  <input-textarea v-model="text" resizeable="none"></input-textarea>
</div>

<script>
new Vue({
  el: '#app',
  
  data: () => ({ text: '' })
})
</script>
````

#### InputTypeahead

## Other Components

#### Alert

#### Breadcrumb

#### Dropdown

#### Modal

#### Icon

#### SmartForm

## Internals

#### Search

#### Typeahead
